(***************************************************************************************************************)
(******                       This is the FeynRules mod-file for the Unbroken Standard model              ******)
(******                                                                                                   ******)
(******     Authors: J. Santiago                                                                          ******)
(******                                                                                                   ******)
(****** Choose whether Feynman gauge is desired.                                                          ******)
(****** If set to False, unitary gauge is assumed.                                                          ****)
(****** Feynman gauge is especially useful for CalcHEP/CompHEP where the calculation is 10-100 times faster. ***)
(****** Feynman gauge is not supported in MadGraph and Sherpa.                                              ****)
(***************************************************************************************************************)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "Unbroken Standard Model";

M$Information = {
  Authors      -> {"J. Santiago"}, 
  Version      -> "1.0",
  Date         -> "17. 03. 2015",
  Institutions -> {"CAFPE and Universidad de Granada"},
  Emails       -> {"jsantiago@ugr.es"}
};

FeynmanGauge = True;

(* ************************** *)
(* *****  Gauge groups  ***** *)
(* ************************** *)
M$GaugeGroups = {
  U1Y  == { 
    Abelian          -> True,  
    CouplingConstant -> g1, 
    GaugeBoson       -> B, 
    Charge           -> Y
  },
  SU2L == { 
    Abelian           -> False, 
    CouplingConstant  -> gw, 
    GaugeBoson        -> Wi, 
    StructureConstant -> Eps, 
    Representations   -> {Ta,SU2D}, 
    Definitions       -> {Ta[a_,b_,c_]->PauliSigma[a,b,c]/2, FSU2L[i_,j_,k_]:> I Eps[i,j,k]}
  },
  SU3C == { 
    Abelian           -> False, 
    CouplingConstant  -> gs, 
    GaugeBoson        -> G,
    StructureConstant -> f, 
    Representations   -> {T,Colour}, 
    SymmetricTensor   -> dSUN
  } 
};


(* ************************** *)
(* *****    Indices     ***** *)
(* ************************** *)

IndexRange[Index[SU2W      ]] = Unfold[Range[3]]; 
IndexRange[Index[SU2D      ]] = Unfold[Range[2]];
IndexRange[Index[Gluon     ]] = NoUnfold[Range[8]];
IndexRange[Index[Colour    ]] = NoUnfold[Range[3]]; 
IndexRange[Index[Generation]] = Range[3];

IndexStyle[SU2W,       j];
IndexStyle[SU2D,       k];
IndexStyle[Gluon,      a];
IndexStyle[Colour,     m];
IndexStyle[Generation, f];


(* ************************** *)
(* **** Particle classes **** *)
(* ************************** *)
M$ClassesDescription = {

(* Gauge bosons: physical vector fields *)
  V[4] == {
    ClassName        -> G,
    SelfConjugate    -> True,
    Indices          -> {Index[Gluon]},
    Mass             -> 0,
    Width            -> 0
},


  V[2] == { 
    ClassName       -> wi, 
    ClassMembers     -> {W1, W2, W3},
    Indices       -> {Index[SU2W]},
    FlavorIndex   -> SU2W,
    SelfConjugate   -> True,
    Mass            -> 0,
    Width           -> 0
  },


  V[11] == { 
    ClassName     -> B, 
    SelfConjugate -> True,
    Mass             -> 0,
    Width            -> 0
  },


(* Gauge bosons: unphysical vector fields *)


  V[12] == { 
    ClassName     -> Wi,
    Unphysical    -> True,
    SelfConjugate -> True, 
    Indices       -> {Index[SU2W]},
    FlavorIndex   -> SU2W,
    Definitions   -> { Wi[mu_,1] -> W1[mu], Wi[mu_,2] -> W2[mu], Wi[mu_,3] -> W3[mu]}
  },


(* Ghosts: related to physical gauge bosons *)

  U[4] == { 
    ClassName       -> ghG, 
    SelfConjugate   -> False,
    Indices         -> {Index[Gluon]},
    Ghost           -> G,
    PDG             -> 82,
    QuantumNumbers  ->{GhostNumber -> 1}, 
    Mass            -> 0,
    Width	    -> 0
  },


  U[1] == { 
    ClassName       -> ghwi, 
    ClassMembers     -> {ghW1, ghW2, ghW3},
    Indices       -> {Index[SU2W]},
    FlavorIndex   -> SU2W,
    SelfConjugate   -> False,
    Ghost           -> wi,
    QuantumNumbers  -> {GhostNumber -> 1},
    Mass            -> 0,
    Width	    -> 0
  },

  U[11] == {
    ClassName     -> ghB, 
    SelfConjugate -> False,
    Ghost         -> B, 
    QuantumNumbers  ->{GhostNumber -> 1}, 
    Mass            -> 0,
    Width	    -> 0
  },

(* Ghosts: related to unphysical gauge bosons *)

  U[12] == {
    ClassName     -> ghWi,
    Unphysical    -> True,
    SelfConjugate -> False,
    Ghost         -> Wi,
    Indices       -> {Index[SU2W]},
    FlavorIndex   -> SU2W,
    Definitions   -> { ghWi[1] -> ghW1, ghWi[2] -> ghW2, ghWi[3] -> ghW3}
  } ,


(* Fermions: physical fields *)
  F[1] == {
    ClassName        -> vl,
    ClassMembers     -> {ve,vm,vt},
    Indices          -> {Index[Generation]},
    FlavorIndex      -> Generation,
    SelfConjugate    -> False,
    Mass             -> 0,
    Width            -> 0,
    QuantumNumbers   -> {LeptonNumber -> 1, Y -> -1/2}
  },
  F[2] == {
    ClassName        -> lL,
    ClassMembers     -> {eL, muL, taL},
    Indices          -> {Index[Generation]},
    FlavorIndex      -> Generation,
    SelfConjugate    -> False,
    Mass             -> 0,
    Width            -> 0,
    QuantumNumbers   -> {LeptonNumber -> 1, Y -> -1/2}
    (*QuantumNumbers   -> {Q -> -1, LeptonNumber -> 1}*)
  },
  F[3] == {
    ClassName        -> lR,
    ClassMembers     -> {eR, muR, taR},
    Indices          -> {Index[Generation]},
    FlavorIndex      -> Generation,
    SelfConjugate    -> False,
    Mass             -> 0,
    Width            -> 0,
    QuantumNumbers   -> {LeptonNumber -> 1, Y -> -1}
(*    QuantumNumbers   -> {Q -> -1, LeptonNumber -> 1}*)
  },


  F[4] == {
    ClassName        -> uqL,
    ClassMembers     -> {uL, cL, tL},
    Indices          -> {Index[Generation], Index[Colour]},
    FlavorIndex      -> Generation,
    SelfConjugate    -> False,
    QuantumNumbers -> {Y -> 1/6},
    Mass             -> 0,
    Width            -> 0
(*    QuantumNumbers   -> {Q -> 2/3}*)
  },

  F[5] == {
    ClassName        -> uqR,
    ClassMembers     -> {uR, cR, tR},
    Indices          -> {Index[Generation], Index[Colour]},
    FlavorIndex      -> Generation,
    SelfConjugate    -> False,
    QuantumNumbers -> {Y -> 2/3},
    Mass             -> 0,
    Width            -> 0(*,
    QuantumNumbers   -> {Q -> 2/3}*)
  },

  F[6] == {
    ClassName        -> dqL,
    ClassMembers     -> {dL, sL, bL},
    Indices          -> {Index[Generation], Index[Colour]},
    FlavorIndex      -> Generation,
    SelfConjugate    -> False,
    Mass             -> 0,
    Width            -> 0,
    QuantumNumbers   -> {Y -> 1/6}
  },

  F[7] == {
    ClassName        -> dqR,
    ClassMembers     -> {dR, sR, bR},
    Indices          -> {Index[Generation], Index[Colour]},
    FlavorIndex      -> Generation,
    SelfConjugate    -> False,
    Mass             -> 0,
    Width            -> 0,
    QuantumNumbers   -> {Y -> -1/3}
  },


(* Fermions: unphysical fields *)

  F[11] == { 
    ClassName      -> LL, 
    Unphysical     -> True, 
    Indices        -> {Index[SU2D], Index[Generation]},
    FlavorIndex    -> SU2D,
    SelfConjugate  -> False,
    QuantumNumbers -> {Y -> -1/2},
    Definitions    -> { LL[sp1_,1,ff_] :> Module[{sp2}, ProjM[sp1,sp2] vl[sp2,ff]], LL[sp1_,2,ff_] :> Module[{sp2}, ProjM[sp1,sp2] lL[sp2,ff]] }
  },

  F[12] == { 
    ClassName      -> LR, 
    Unphysical     -> True, 
    Indices        -> {Index[Generation]},
    FlavorIndex    -> Generation,
    SelfConjugate  -> False,
    QuantumNumbers -> {Y -> -1},
    Definitions    -> { LR[sp1_,ff_] :> Module[{sp2}, ProjP[sp1,sp2] lR[sp2,ff]] }
  },

  F[13] == { 
    ClassName      -> QL, 
    Unphysical     -> True, 
    Indices        -> {Index[SU2D], Index[Generation], Index[Colour]},
    FlavorIndex    -> SU2D,
    SelfConjugate  -> False,
    QuantumNumbers -> {Y -> 1/6},
    Definitions    -> { 
      QL[sp1_,1,ff_,cc_] :> Module[{sp2}, ProjM[sp1,sp2] uqL[sp2,ff,cc]], 
      QL[sp1_,2,ff_,cc_] :> Module[{sp2}, ProjM[sp1,sp2] dqL[sp2,ff,cc]] }
  },

  F[14] == { 
    ClassName      -> UR, 
    Unphysical     -> True, 
    Indices        -> {Index[Generation], Index[Colour]},
    FlavorIndex    -> Generation,
    SelfConjugate  -> False,
    QuantumNumbers -> {Y -> 2/3},
    Definitions    -> { UR[sp1_,ff_,cc_] :> Module[{sp2}, ProjP[sp1,sp2] uqR[sp2,ff,cc]] }
  },

  F[15] == { 
    ClassName      -> DR, 
    Unphysical     -> True, 
    Indices        -> {Index[Generation], Index[Colour]},
    FlavorIndex    -> Generation,
    SelfConjugate  -> False,
    QuantumNumbers -> {Y -> -1/3},
    Definitions    -> { DR[sp1_,ff_,cc_] :> Module[{sp2}, ProjP[sp1,sp2] dqR[sp2,ff,cc]] }
  },



(* Higgs: physical scalars  *)
  S[1] == {
    ClassName       -> H1,
    SelfConjugate   -> False,
    QuantumNumbers -> {Y -> 1/2},
    Mass            -> 0,
    Width           -> 0
  },

  S[2] == {
    ClassName       -> H2,
    SelfConjugate   -> False,
    QuantumNumbers -> {Y -> 1/2},
    Mass            -> 0,
    Width           -> 0
  },

(* Higgs: unphysical scalars  *)
  S[11] == { 
    ClassName      -> Phi, 
    Unphysical     -> True, 
    Indices        -> {Index[SU2D]},
    FlavorIndex    -> SU2D,
    SelfConjugate  -> False,
    QuantumNumbers -> {Y -> 1/2},
    Definitions    -> { Phi[1] -> H1, Phi[2] -> H2  }
  }


};


(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {

  (* External parameters *)

  (* Internal Parameters *)
  gw == { 
    ParameterType    -> Internal
  },
  g1 == { 
    ParameterType    -> Internal
  },
  gs == { 
    ParameterType    -> Internal
  },

  lam == {
    ParameterType    -> Internal
  },
  muH == {
    ParameterType -> Internal
  },
  yl == {
    ParameterType    -> Internal,
    Indices          -> {Index[Generation], Index[Generation]}
  },
  yu == {
    ParameterType    -> Internal,
    Indices          -> {Index[Generation], Index[Generation]}
  },
  yd == {
    ParameterType    -> Internal,
    Indices          -> {Index[Generation], Index[Generation]}
  }
};



